@@ -16,7 +16,7 @@ use strict;
 
 our ( $VERSION, $COMPATIBLE, $FILENAME );
 
-$VERSION = '1.074';
+$VERSION = '1.075';
 $COMPATIBLE = '0.07';
 $FILENAME=__FILE__;
 
@@ -795,70 +795,3 @@ sub _Parse {
 
 1;
 
-=head1 NAME 
-
-Parse::Eyapp::Driver - LR Parser and methods to support parsing
- 
-=head1 SEE ALSO
-  
-No documentation here. To learn about Parse::Eyapp::Driver see:
-
-=over
-
-=item * L<Parse::Eyapp>,
-
-=item * L<eyapptut>
-
-=item * The pdf files in L<http://nereida.deioc.ull.es/~pl/perlexamples/Eyapp.pdf> and  
-L<http://nereida.deioc.ull.es/~pl/perlexamples/eyapptut.pdf>.
-
-=item * L<http://nereida.deioc.ull.es/~pl/perlexamples/section_eyappts.html> (Spanish),
-
-=item * L<eyapp>,
-
-=item * L<treereg>,
-
-=item * L<Parse::yapp>,
-
-=item * yacc(1),
-
-=item * bison(1),
-
-=item * the classic book "Compilers: Principles, Techniques, and Tools" by Alfred V. Aho, Ravi Sethi and
-
-=item * Jeffrey D. Ullman (Addison-Wesley 1986)
-
-=item * L<Parse::RecDescent>.
-
-=back
-
-=head1 AUTHOR
- 
-Casiano Rodriguez-Leon (casiano@ull.es)
- 
-=head1 ACKNOWLEDGMENTS
-
-This work has been supported by CEE (FEDER) and the Spanish Ministry of
-Educacin y Ciencia through Plan Nacional I+D+I number TIN2005-08818-C04-04
-(ULL::OPLINK project). Support from Gobierno de Canarias was through GC02210601
-(Grupos Consolidados).
-The University of La Laguna has also supported my work in many ways
-and for many years.
-I wish to thank Francois Desarmenien for his C<Parse::Yapp> module,
-to my students at La Laguna and to the Perl Community. Special thanks to
-my family and Larry Wall.
-
-=head1 LICENCE AND COPYRIGHT
-
-Copyright (c) 2006 Casiano Rodriguez-Leon (casiano@ull.es). All rights reserved.
-
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-
-=cut
-
-
